pub enum SimpleType {
Array,
Boolean,
Integer,
Null,
Number,
Object,
String,
}Expand description
Primitive type names defined by JSON Schema (simpleTypes).
String values MUST be one of the six primitive types ("null",
"boolean", "object", "array", "number", or "string"), or
"integer" which matches any number with a zero fractional part.
Variants
Array
A JSON array (ordered sequence of values).
Boolean
A JSON true or false value.
Integer
A JSON number with a zero fractional part (subset of Number).
Null
The JSON null value.
Number
A JSON number (any numeric value, including integers).
Object
A JSON object (unordered set of name/value pairs).
String
A JSON string.