pub enum TypeValue {
Single(SimpleType),
Union(Vec<SimpleType>),
}Expand description
The value of the JSON Schema type keyword.
The value of this keyword MUST be either a string or an array. If it is an array, elements of the array MUST be strings and MUST be unique.
Variants
Single(SimpleType)
A single type constraint, e.g. "type": "string".
Union(Vec<SimpleType>)
A union of types, e.g. "type": ["string", "null"].
The array SHOULD have at least one element, and elements MUST be unique.