pub fn schema() -> ValueExpand description
Generate the JSON Schema for SchemaValue (a JSON Schema 2020-12
document).
Panics
Panics if the generated schema cannot be serialized to
serde_json::Value (should never happen in practice).
pub fn schema() -> ValueGenerate the JSON Schema for SchemaValue (a JSON Schema 2020-12
document).
Panics if the generated schema cannot be serialized to
serde_json::Value (should never happen in practice).