pub struct FormatAnnotationVocabulary {
pub format: Option<String>,
}Expand description
Format-annotation vocabulary.
Fields
format: Option<String>The format keyword — semantic format annotation.
Structural validation alone may be insufficient to allow an
application to correctly utilize certain values. The "format"
annotation keyword is defined to allow schema authors to convey
semantic information for a fixed subset of values which are
accurately described by authoritative resources, be they RFCs or
other external specifications.
The value of this keyword is called a format attribute. It MUST be a string.